{% extends "../_base.html" %}


{% block main %}
  <section class="row">
    <h2>{{ project.name }}</h2>

    <article class="col-md-10">
      <p>
        {{ project.description }}
      </p>
      <img class="pygal" src="{{ reverse_url('ProjectChartTime',
      project.project_id) }}" alt="ProjectChartTime graph"/>
      {% for chart in server.components.project_charts %}
        <img class="pygal" src="{{ reverse_url(chart.__name__,
        project.project_id) }}" alt="{{ chart.__name__ }} graph"/>
      {% end %}
    </article>
    <article class="col-md-2 block" data-block="history" data-args="/{{ project.project_id }}"></article>
  </section>
{% end %}
