{% extends "../_base.html" %}


{% block main %}
  <h2>{{ project.name }} build #{{ build.build_id }} [{{ build.status }}]</h2>
  <code class="out"
  {% if not log %}
    data-id="{{ project.project_id }}" data-idx="{{ build.build_id }}"
  {% end %}
  >
    {{ log or ''}}
  </code>
{% end %}

{% block js %}
  {% if not log %}
    <script src="{{ static_url('log.js') }}"></script>
  {% end %}
{% end %}
