{% extends "_base.html" %}

{% block main %}
  <h1>YMCI</h1>
  <section class="row">
    <article class="col-md-10 block" data-block="home">
    </article>

    <article class="col-md-2 block" data-block="build">
    </article>
  </section>
{% end %}
