@font-face {
  font-family: "Source Code Pro";
  src: url("/static/fonts/SourceCodePro-Regular.ttf.woff") format("woff");
  font-weight: 400; }

@font-face {
  font-family: "Source Code Pro";
  src: url("/static/fonts/SourceCodePro-Semibold.ttf.woff") format("woff");
  font-weight: 700; }

@font-face {
  font-family: "Source Code Pro";
  src: url("/static/fonts/SourceCodePro-Bold.ttf.woff") format("woff");
  font-weight: 900; }
