{% extends "_base.html" %}

{% block main %}
  <form class="form-horizontal" method="post">
    <fieldset>
      <legend>{{ getattr(form, 'form_name', form.__class__.__name__) }}</legend>
      {% raw render_form_recursively(form) %}
    </fieldset>
    <div class="form-group">
      <div class="col-sm-offset-2 col-sm-10">
        <input type="submit" class="btn btn-default btn-primary" />
        <a class="btn btn-default" href="javascript:window.history.go(-1)">Back</a>
      </div>
    </div>
  </form>
{% end %}
