{% for name, field in form._fields.items() %}
  <div class="form-group">
    {% if field.errors %}
      {% raw field.label(class_="col-lg-2 control-label", title=', '.join(field.errors)) %}
    {% else %}
      {% raw field.label(class_="col-lg-2 control-label") %}
    {% end %}
    <div class="col-lg-10">
      {% if field.type != 'ModelFormField' %}
        {% raw field(class_="form-control", placeholder=field.label.text) %}
      {% else %}
        {% raw render_form_recursively(field) %}
      {% end %}
    </div>
  </div>
{% end %}
