{% extends "_base.html" %}

{% block main %}
  <section class="row">
    <article class="col-md-10 scroll-x">
      {{ path }}
      {% if code %}
        {% raw code %}
      {% else %}
        <embed src="{{ reverse_url('BrowseRaw', project.project_id, build_id, path) }}"></embed>
      {% end %}
    </article>

    <article class="col-md-2">
      <select name="build-select">
        {% for b in project.builds %}
          <option value="{{ reverse_url('ProjectBrowse', project.project_id, b.build_id, path) }}" {% raw "selected=\"selected\"" if b.build_id == int(build_id) else '' %}>Build {{ b.build_id }}</option>
        {% end %}
      </select>

      <aside class="tree">
        {% raw tree %}
      </aside>
    </article>
  </section>
{% end %}
